---
short-description: Videos about Meson
...

# Videos

 - [Lessons Learned From Porting LibreOffice's Build System To
   Meson](https://www.youtube.com/watch?v=asB_hx_jJSw), CppNorth 2022

 - [The Meson build system
   overview](https://www.youtube.com/watch?v=rewhp5o0xZg), PyCon US
   2022

 - [Behind (and under) the scenes of the Meson build
   system](https://www.youtube.com/watch?v=iLN6wL7ExHU), Linux.conf.au
   2020

 - [Behind the Scenes of a C++ Build
   System](https://www.youtube.com/watch?v=34KzT2yvQuM), CppCon 2019

 - [Compiling Multi-Million Line C++ Code Bases Effortlessly with the
   Meson Build system](https://www.youtube.com/watch?v=SCZLnopmYBM),
   CppCon 2018

 - [The Meson Build System, 4+ years of work to become an overnight
   success](https://www.youtube.com/watch?v=gHdTzdXkhRY), Linux.conf.au 2018

 - [Power through simplicity, using Python in the Meson Build
   System](https://youtu.be/3jF3oVsjIEM), Piter.py, 2017

 - [Meson and the changing Linux build
   landscape](https://media.ccc.de/v/ASG2017-111-meson_and_the_changing_linux_build_landscape),
   All Systems Go 2017

 - [Meson, compiling the world with
   Python](https://www.youtube.com/watch?v=sEO4DC8hm34), Europython
   2017

 - [Builds, dependencies and deployment in a modern multiplatform
   world](https://www.youtube.com/embed/CTJtKtQ8R5k), Linux.conf.au
   2016

 - [New world, new tools](https://www.youtube.com/embed/0-gx1qU2pPo),
   Libre Application Summit 2016

 - [Making build systems not
   suck](https://www.youtube.com/embed/KPi0AuVpxLI), Linux.conf.au
   2015, Auckland, New Zealand

 - [Lightning talk at FOSDEM
   2014](http://mirror.onet.pl/pub/mirrors/video.fosdem.org/2014/H2215_Ferrer/Sunday/Introducing_the_Meson_build_system.webm),
   The first ever public presentation on Meson
